StructuredEmbeddingInteraction
==============================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: StructuredEmbeddingInteraction
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~StructuredEmbeddingInteraction.relation_shape

   .. rubric:: Methods Summary

   .. autosummary::

      ~StructuredEmbeddingInteraction.func

   .. rubric:: Attributes Documentation

   .. autoattribute:: relation_shape

   .. rubric:: Methods Documentation

   .. automethod:: func
